# IO.Swagger.Api.HistoricalApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CategoriesGet**](HistoricalApi.md#categoriesget) | **GET** /categories | Get historical stats for categories
[**CategoryGet**](HistoricalApi.md#categoryget) | **GET** /category | Get history for category ID
[**DomainGet**](HistoricalApi.md#domainget) | **GET** /domain | Get history for domain name
[**DomainsGet**](HistoricalApi.md#domainsget) | **GET** /domains | Get historical stats for domains
[**PageGet**](HistoricalApi.md#pageget) | **GET** /page | Get page history for URL
[**PagesGet**](HistoricalApi.md#pagesget) | **GET** /pages | Get historical stats for pages

<a name="categoriesget"></a>
# **CategoriesGet**
> List<Categories> CategoriesGet (string country, string subcountry, string fromDate, string toDate, string keywordFilter, int? lines, int? offset)

Get historical stats for categories

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CategoriesGetExample
    {
        public void main()
        {


            var apiInstance = new HistoricalApi();
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var fromDate = fromDate_example;  // string | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var toDate = toDate_example;  // string | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var keywordFilter = keywordFilter_example;  // string | Filter answers to cateogry names containing a particular keyword (optional) 
            var lines = 56;  // int? | Get X results (max in one request is 10K please use offset paginated results if you need more) (optional)  (default to 50)
            var offset = 56;  // int? | Get paginated results from X offset (optional)  (default to 0)

            try
            {
                // Get historical stats for categories
                List&lt;Categories&gt; result = apiInstance.CategoriesGet(country, subcountry, fromDate, toDate, keywordFilter, lines, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling HistoricalApi.CategoriesGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **fromDate** | **string**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **string**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **keywordFilter** | **string**| Filter answers to cateogry names containing a particular keyword | [optional] 
 **lines** | **int?**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int?**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List<Categories>**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="categoryget"></a>
# **CategoryGet**
> List<Category> CategoryGet (string id, string country, string subcountry, string fromDate, string toDate)

Get history for category ID

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CategoryGetExample
    {
        public void main()
        {


            var apiInstance = new HistoricalApi();
            var id = id_example;  // string | category id
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var fromDate = fromDate_example;  // string | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var toDate = toDate_example;  // string | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 

            try
            {
                // Get history for category ID
                List&lt;Category&gt; result = apiInstance.CategoryGet(id, country, subcountry, fromDate, toDate);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling HistoricalApi.CategoryGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| category id | 
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **fromDate** | **string**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **string**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**List<Category>**](Category.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="domainget"></a>
# **DomainGet**
> List<Domain> DomainGet (string domain, string country, string subcountry, string fromDate, string toDate)

Get history for domain name

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DomainGetExample
    {
        public void main()
        {


            var apiInstance = new HistoricalApi();
            var domain = domain_example;  // string | domain name (no subdomain allowed)
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var fromDate = fromDate_example;  // string | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var toDate = toDate_example;  // string | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 

            try
            {
                // Get history for domain name
                List&lt;Domain&gt; result = apiInstance.DomainGet(domain, country, subcountry, fromDate, toDate);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling HistoricalApi.DomainGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **domain** | **string**| domain name (no subdomain allowed) | 
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **fromDate** | **string**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **string**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**List<Domain>**](Domain.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="domainsget"></a>
# **DomainsGet**
> List<Domains> DomainsGet (string country, string subcountry, string fromDate, string toDate, string urlFilter, int? lines, int? offset)

Get historical stats for domains

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DomainsGetExample
    {
        public void main()
        {


            var apiInstance = new HistoricalApi();
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var fromDate = fromDate_example;  // string | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var toDate = toDate_example;  // string | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var urlFilter = urlFilter_example;  // string | Filter answers to domains including a specified string (optional) 
            var lines = 56;  // int? | Get X results (max in one request is 10K please use offset paginated results if you need more) (optional)  (default to 50)
            var offset = 56;  // int? | Get paginated results from X offset (optional)  (default to 0)

            try
            {
                // Get historical stats for domains
                List&lt;Domains&gt; result = apiInstance.DomainsGet(country, subcountry, fromDate, toDate, urlFilter, lines, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling HistoricalApi.DomainsGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **fromDate** | **string**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **string**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **urlFilter** | **string**| Filter answers to domains including a specified string | [optional] 
 **lines** | **int?**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int?**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List<Domains>**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="pageget"></a>
# **PageGet**
> List<Page> PageGet (string url, string country, string subcountry, string fromDate, string toDate)

Get page history for URL

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class PageGetExample
    {
        public void main()
        {


            var apiInstance = new HistoricalApi();
            var url = url_example;  // string | Fully qualified page url. URL needs to be URL encoded
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var fromDate = fromDate_example;  // string | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 
            var toDate = toDate_example;  // string | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional) 

            try
            {
                // Get page history for URL
                List&lt;Page&gt; result = apiInstance.PageGet(url, country, subcountry, fromDate, toDate);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling HistoricalApi.PageGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **string**| Fully qualified page url. URL needs to be URL encoded | 
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **fromDate** | **string**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **toDate** | **string**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**List<Page>**](Page.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="pagesget"></a>
# **PagesGet**
> List<Pages> PagesGet (int? presetFilter, string fromDate, string toDate, string country, string subcountry, string domainFilter, string urlFilter, int? categoryFilter, string keywordFilter, int? lines, int? offset)

Get historical stats for pages

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class PagesGetExample
    {
        public void main()
        {


            var apiInstance = new HistoricalApi();
            var presetFilter = 56;  // int? | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
            var fromDate = fromDate_example;  // string | Datas from YYYY-MM-DD (if not provided, last 30 days) (optional) 
            var toDate = toDate_example;  // string | Datas to YYYY-MM-DD (if not provided, last 30 days) (optional) 
            var country = country_example;  // string | ISO_3166 country code in 2 letters (if not provided  worldwide) (optional) 
            var subcountry = subcountry_example;  // string | state code (optional) 
            var domainFilter = domainFilter_example;  // string | Filter answers to pages of a designated domain name (optional) 
            var urlFilter = urlFilter_example;  // string | Filter answers to pages URL including a specified string (optional) 
            var categoryFilter = 56;  // int? | Filter answers to a specific page category (optional) 
            var keywordFilter = keywordFilter_example;  // string | Filter answers to pages titles containing a particular keyword (optional) 
            var lines = 56;  // int? | Get X results (max in one request is 50 please use offset paginated results if you need more) (optional)  (default to 50)
            var offset = 56;  // int? | Get paginated results from X offset (optional)  (default to 0)

            try
            {
                // Get historical stats for pages
                List&lt;Pages&gt; result = apiInstance.PagesGet(presetFilter, fromDate, toDate, country, subcountry, domainFilter, urlFilter, categoryFilter, keywordFilter, lines, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling HistoricalApi.PagesGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **presetFilter** | **int?**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone | 
 **fromDate** | **string**| Datas from YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **toDate** | **string**| Datas to YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **country** | **string**| ISO_3166 country code in 2 letters (if not provided  worldwide) | [optional] 
 **subcountry** | **string**| state code | [optional] 
 **domainFilter** | **string**| Filter answers to pages of a designated domain name | [optional] 
 **urlFilter** | **string**| Filter answers to pages URL including a specified string | [optional] 
 **categoryFilter** | **int?**| Filter answers to a specific page category | [optional] 
 **keywordFilter** | **string**| Filter answers to pages titles containing a particular keyword | [optional] 
 **lines** | **int?**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int?**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List<Pages>**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

