# IO.Swagger.Api.LiveApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**LivecategoriesGet**](LiveApi.md#livecategoriesget) | **GET** /livecategories | Get livedata stats for categories
[**LivedomainsGet**](LiveApi.md#livedomainsget) | **GET** /livedomains | Get livedata stats for domains
[**LivepagesGet**](LiveApi.md#livepagesget) | **GET** /livepages | Get livedata stats for pages

<a name="livecategoriesget"></a>
# **LivecategoriesGet**
> List<Categories> LivecategoriesGet (string country, string subcountry, int? hours, string keywordFilter, string languageFilter, int? lines, int? offset)

Get livedata stats for categories

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class LivecategoriesGetExample
    {
        public void main()
        {


            var apiInstance = new LiveApi();
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var hours = 56;  // int? | Get results for last x hours (optional) 
            var keywordFilter = keywordFilter_example;  // string | Filter answers to category names containing a particular keyword (optional) 
            var languageFilter = languageFilter_example;  // string | Filter answers to pages in specific user language (optional) 
            var lines = 56;  // int? | Get X results (max in one request is 10K please use offset paginated results if you need more) (optional)  (default to 50)
            var offset = 56;  // int? | Get paginated results from X offset (optional)  (default to 0)

            try
            {
                // Get livedata stats for categories
                List&lt;Categories&gt; result = apiInstance.LivecategoriesGet(country, subcountry, hours, keywordFilter, languageFilter, lines, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling LiveApi.LivecategoriesGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **hours** | **int?**| Get results for last x hours | [optional] 
 **keywordFilter** | **string**| Filter answers to category names containing a particular keyword | [optional] 
 **languageFilter** | **string**| Filter answers to pages in specific user language | [optional] 
 **lines** | **int?**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int?**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List<Categories>**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="livedomainsget"></a>
# **LivedomainsGet**
> List<Domains> LivedomainsGet (string country, string subcountry, string urlFilter, int? hours, int? lines, string languageFilter, int? offset)

Get livedata stats for domains

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class LivedomainsGetExample
    {
        public void main()
        {


            var apiInstance = new LiveApi();
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var subcountry = subcountry_example;  // string | state code (optional) 
            var urlFilter = urlFilter_example;  // string | Filter answers to domains including a specified string (optional) 
            var hours = 56;  // int? | Get results for last x hours (optional) 
            var lines = 56;  // int? | Get X results (max in one request is 10K please use offset paginated results if you need more) (optional)  (default to 50)
            var languageFilter = languageFilter_example;  // string | Filter answers to pages in specific user language (optional) 
            var offset = 56;  // int? | Get paginated results from X offset (optional)  (default to 0)

            try
            {
                // Get livedata stats for domains
                List&lt;Domains&gt; result = apiInstance.LivedomainsGet(country, subcountry, urlFilter, hours, lines, languageFilter, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling LiveApi.LivedomainsGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **subcountry** | **string**| state code | [optional] 
 **urlFilter** | **string**| Filter answers to domains including a specified string | [optional] 
 **hours** | **int?**| Get results for last x hours | [optional] 
 **lines** | **int?**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **languageFilter** | **string**| Filter answers to pages in specific user language | [optional] 
 **offset** | **int?**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List<Domains>**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="livepagesget"></a>
# **LivepagesGet**
> List<Pages> LivepagesGet (string country, int? presetFilter, string subcountry, int? hours, int? onlyNew, string domainFilter, string keywordFilter, string urlFilter, int? categoryFilter, string languageFilter, int? lines, int? offset)

Get livedata stats for pages

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class LivepagesGetExample
    {
        public void main()
        {


            var apiInstance = new LiveApi();
            var country = country_example;  // string | ISO_3166 country code in 2 letters
            var presetFilter = 56;  // int? | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
            var subcountry = subcountry_example;  // string | state code (optional) 
            var hours = 56;  // int? | Get results for last x hours (optional) 
            var onlyNew = 56;  // int? | Get only pages first seen in the reporting period if set on 1 (optional)  (default to 0)
            var domainFilter = domainFilter_example;  // string | Filter answers to pages of a designated domain name (optional) 
            var keywordFilter = keywordFilter_example;  // string | Filter answers to pages titles containing a particular keyword (optional) 
            var urlFilter = urlFilter_example;  // string | Filter answers to pages URL including a specified string (optional) 
            var categoryFilter = 56;  // int? | Filter answers to pages of a designated category id (optional) 
            var languageFilter = languageFilter_example;  // string | Filter answers to pages in specific user language (optional) 
            var lines = 56;  // int? | Get X results (max in one request is 50 please use offset paginated results if you need more) (optional)  (default to 50)
            var offset = 56;  // int? | Get paginated results from X offset (optional)  (default to 0)

            try
            {
                // Get livedata stats for pages
                List&lt;Pages&gt; result = apiInstance.LivepagesGet(country, presetFilter, subcountry, hours, onlyNew, domainFilter, keywordFilter, urlFilter, categoryFilter, languageFilter, lines, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling LiveApi.LivepagesGet: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **string**| ISO_3166 country code in 2 letters | 
 **presetFilter** | **int?**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone | 
 **subcountry** | **string**| state code | [optional] 
 **hours** | **int?**| Get results for last x hours | [optional] 
 **onlyNew** | **int?**| Get only pages first seen in the reporting period if set on 1 | [optional] [default to 0]
 **domainFilter** | **string**| Filter answers to pages of a designated domain name | [optional] 
 **keywordFilter** | **string**| Filter answers to pages titles containing a particular keyword | [optional] 
 **urlFilter** | **string**| Filter answers to pages URL including a specified string | [optional] 
 **categoryFilter** | **int?**| Filter answers to pages of a designated category id | [optional] 
 **languageFilter** | **string**| Filter answers to pages in specific user language | [optional] 
 **lines** | **int?**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int?**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List<Pages>**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

