using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IAlertsApi
    {
        /// <summary>
        /// Edit or insert new alert 
        /// </summary>
        /// <param name="id">ID of the alert to edit ; if adding a new one leave blank</param>
        /// <param name="alertname">Name of the alert</param>
        /// <param name="activated">Should the alert be activated or not</param>
        /// <param name="type">Alert type (1&#x3D; New content for website, 2&#x3D;New perfirming contents)</param>
        /// <param name="channel">1 for email, 2 for Slack, 3 for Google Chat</param>
        /// <param name="recipient">Email address of recipient or webhook for Slack/Gchat</param>
        /// <param name="param1">Parameter 1 (meaning changes with alert type)</param>
        /// <param name="param2">Parameter 2 (meaning changes with alert type)</param>
        /// <param name="param3">Parameter 3 (meaning changes with alert type)</param>
        /// <param name="param4">Parameter 4 (meaning changes with alert type)</param>
        /// <param name="param5">Parameter 5 (meaning changes with alert type)</param>
        /// <returns>List&lt;Domains&gt;</returns>
        List<Domains> AlertsChangeGet (string id, string alertname, bool? activated, int? type, int? channel, string recipient, string param1, string param2, string param3, string param4, string param5);
        /// <summary>
        /// Permanently delete the alert 
        /// </summary>
        /// <param name="id">alert id to delete</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> AlertsDeleteGet (string id);
        /// <summary>
        /// Get alerts for user account 
        /// </summary>
        /// <returns>List&lt;Alerts&gt;</returns>
        List<Alerts> AlertsGet ();
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class AlertsApi : IAlertsApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AlertsApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public AlertsApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="AlertsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public AlertsApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Edit or insert new alert 
        /// </summary>
        /// <param name="id">ID of the alert to edit ; if adding a new one leave blank</param>
        /// <param name="alertname">Name of the alert</param>
        /// <param name="activated">Should the alert be activated or not</param>
        /// <param name="type">Alert type (1&#x3D; New content for website, 2&#x3D;New perfirming contents)</param>
        /// <param name="channel">1 for email, 2 for Slack, 3 for Google Chat</param>
        /// <param name="recipient">Email address of recipient or webhook for Slack/Gchat</param>
        /// <param name="param1">Parameter 1 (meaning changes with alert type)</param>
        /// <param name="param2">Parameter 2 (meaning changes with alert type)</param>
        /// <param name="param3">Parameter 3 (meaning changes with alert type)</param>
        /// <param name="param4">Parameter 4 (meaning changes with alert type)</param>
        /// <param name="param5">Parameter 5 (meaning changes with alert type)</param>
        /// <returns>List&lt;Domains&gt;</returns>
        public List<Domains> AlertsChangeGet (string id, string alertname, bool? activated, int? type, int? channel, string recipient, string param1, string param2, string param3, string param4, string param5)
        {
            // verify the required parameter 'id' is set
            if (id == null) throw new ApiException(400, "Missing required parameter 'id' when calling AlertsChangeGet");
            // verify the required parameter 'alertname' is set
            if (alertname == null) throw new ApiException(400, "Missing required parameter 'alertname' when calling AlertsChangeGet");
            // verify the required parameter 'activated' is set
            if (activated == null) throw new ApiException(400, "Missing required parameter 'activated' when calling AlertsChangeGet");
            // verify the required parameter 'type' is set
            if (type == null) throw new ApiException(400, "Missing required parameter 'type' when calling AlertsChangeGet");
            // verify the required parameter 'channel' is set
            if (channel == null) throw new ApiException(400, "Missing required parameter 'channel' when calling AlertsChangeGet");
            // verify the required parameter 'recipient' is set
            if (recipient == null) throw new ApiException(400, "Missing required parameter 'recipient' when calling AlertsChangeGet");
    
            var path = "/alerts_change";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (id != null) queryParams.Add("id", ApiClient.ParameterToString(id)); // query parameter
 if (alertname != null) queryParams.Add("alertname", ApiClient.ParameterToString(alertname)); // query parameter
 if (activated != null) queryParams.Add("activated", ApiClient.ParameterToString(activated)); // query parameter
 if (type != null) queryParams.Add("type", ApiClient.ParameterToString(type)); // query parameter
 if (channel != null) queryParams.Add("channel", ApiClient.ParameterToString(channel)); // query parameter
 if (recipient != null) queryParams.Add("recipient", ApiClient.ParameterToString(recipient)); // query parameter
 if (param1 != null) queryParams.Add("param1", ApiClient.ParameterToString(param1)); // query parameter
 if (param2 != null) queryParams.Add("param2", ApiClient.ParameterToString(param2)); // query parameter
 if (param3 != null) queryParams.Add("param3", ApiClient.ParameterToString(param3)); // query parameter
 if (param4 != null) queryParams.Add("param4", ApiClient.ParameterToString(param4)); // query parameter
 if (param5 != null) queryParams.Add("param5", ApiClient.ParameterToString(param5)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling AlertsChangeGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling AlertsChangeGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Domains>) ApiClient.Deserialize(response.Content, typeof(List<Domains>), response.Headers);
        }
    
        /// <summary>
        /// Permanently delete the alert 
        /// </summary>
        /// <param name="id">alert id to delete</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> AlertsDeleteGet (string id)
        {
            // verify the required parameter 'id' is set
            if (id == null) throw new ApiException(400, "Missing required parameter 'id' when calling AlertsDeleteGet");
    
            var path = "/alerts_delete";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (id != null) queryParams.Add("id", ApiClient.ParameterToString(id)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling AlertsDeleteGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling AlertsDeleteGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Get alerts for user account 
        /// </summary>
        /// <returns>List&lt;Alerts&gt;</returns>
        public List<Alerts> AlertsGet ()
        {
    
            var path = "/alerts";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling AlertsGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling AlertsGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Alerts>) ApiClient.Deserialize(response.Content, typeof(List<Alerts>), response.Headers);
        }
    
    }
}
