using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IFavsApi
    {
        /// <summary>
        /// Create a new fav 
        /// </summary>
        /// <param name="name">Name of the fav.</param>
        /// <param name="action">Action to be opened.</param>
        /// <param name="parameters">Action&#x27;s parameters encoded in JSON.</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> FavsAddGet (string name, string action, string parameters);
        /// <summary>
        /// Permanently delete the fav 
        /// </summary>
        /// <param name="id">ID of the fav to delete.</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> FavsDeleteGet (string id);
        /// <summary>
        /// Get favorites 
        /// </summary>
        /// <param name="id">ID of the requested fav. ignore or set to 0 to get the full favs list</param>
        /// <returns>List&lt;Favs&gt;</returns>
        List<Favs> FavsGet (string id);
        /// <summary>
        /// Update the fav 
        /// </summary>
        /// <param name="id">ID of the fav that should be edited</param>
        /// <param name="name">Name of the fav.</param>
        /// <param name="action">Action to be opened.</param>
        /// <param name="parameters">Action&#x27;s parameters encoded in JSON.</param>
        /// <param name="scheduled">0 if not scheduled, else x in hours</param>
        /// <param name="scheduledto">email address of the recipient of this report</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> FavsUpdateGet (string id, string name, string action, string parameters, int? scheduled, string scheduledto);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class FavsApi : IFavsApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="FavsApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public FavsApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="FavsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public FavsApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Create a new fav 
        /// </summary>
        /// <param name="name">Name of the fav.</param>
        /// <param name="action">Action to be opened.</param>
        /// <param name="parameters">Action&#x27;s parameters encoded in JSON.</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> FavsAddGet (string name, string action, string parameters)
        {
    
            var path = "/favs_add";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (action != null) queryParams.Add("action", ApiClient.ParameterToString(action)); // query parameter
 if (parameters != null) queryParams.Add("parameters", ApiClient.ParameterToString(parameters)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsAddGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsAddGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Permanently delete the fav 
        /// </summary>
        /// <param name="id">ID of the fav to delete.</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> FavsDeleteGet (string id)
        {
    
            var path = "/favs_delete";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (id != null) queryParams.Add("id", ApiClient.ParameterToString(id)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsDeleteGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsDeleteGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Get favorites 
        /// </summary>
        /// <param name="id">ID of the requested fav. ignore or set to 0 to get the full favs list</param>
        /// <returns>List&lt;Favs&gt;</returns>
        public List<Favs> FavsGet (string id)
        {
    
            var path = "/favs";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (id != null) queryParams.Add("id", ApiClient.ParameterToString(id)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Favs>) ApiClient.Deserialize(response.Content, typeof(List<Favs>), response.Headers);
        }
    
        /// <summary>
        /// Update the fav 
        /// </summary>
        /// <param name="id">ID of the fav that should be edited</param>
        /// <param name="name">Name of the fav.</param>
        /// <param name="action">Action to be opened.</param>
        /// <param name="parameters">Action&#x27;s parameters encoded in JSON.</param>
        /// <param name="scheduled">0 if not scheduled, else x in hours</param>
        /// <param name="scheduledto">email address of the recipient of this report</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> FavsUpdateGet (string id, string name, string action, string parameters, int? scheduled, string scheduledto)
        {
            // verify the required parameter 'id' is set
            if (id == null) throw new ApiException(400, "Missing required parameter 'id' when calling FavsUpdateGet");
    
            var path = "/favs_update";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (id != null) queryParams.Add("id", ApiClient.ParameterToString(id)); // query parameter
 if (name != null) queryParams.Add("name", ApiClient.ParameterToString(name)); // query parameter
 if (action != null) queryParams.Add("action", ApiClient.ParameterToString(action)); // query parameter
 if (parameters != null) queryParams.Add("parameters", ApiClient.ParameterToString(parameters)); // query parameter
 if (scheduled != null) queryParams.Add("scheduled", ApiClient.ParameterToString(scheduled)); // query parameter
 if (scheduledto != null) queryParams.Add("scheduledto", ApiClient.ParameterToString(scheduledto)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsUpdateGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling FavsUpdateGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
    }
}
